@@ -22,9 +22,9 @@ from . import s_log , s_db
 #####################################################################
 
 def cleanup( ) :
-    #pass
-    s_db.filepath_delete_all( )
+    #s_db.filepath_delete_all( )
     #s_log.write( "cleanup" )
+    pass
 
 #####################################################################
 
