@@ -127,9 +127,9 @@ def job_request( params = { } ) :
     #####################################################################
 
     headers = { "X-Omni-Action": "job_request" }
-    headers["X-Omni-Params"]=s_util.json_encode(params)
+    headers[ "X-Omni-Params" ] = s_util.json_encode( params )
 
-    s_log.write(headers)
+    s_log.write( headers )
 
     res = get_request_response( headers , payload )
 
@@ -208,6 +208,14 @@ def job_response( jid ) :
         s_log.write( "Not found X-Omni-State" )
         return( False )
 
+
+    s_db.meta_create( "_job_state" , res.headers[ "X-Omni-State" ] ) 
+
+    if( res.headers[ "X-Omni-State" ].startswith( "error_" ) ) :
+        # FIXME TODO should add more info here...
+        s_log.write( "job_response STATE ERROR [" + jid + "]" )
+        return( True )
+
     if( res.headers[ "X-Omni-State" ] != "done" ) :
         s_log.write( "job_response !=Done [" + jid + "]" )
         return( None )
